@@ -2,6 +2,7 @@
 #define __STAN__GM__AST_HPP__
 
 #include <map>
+#include <string>
 #include <vector>
 
 #include <boost/variant/recursive_variant.hpp>
@@ -342,8 +343,9 @@ namespace stan {
     bool has_low() const;
     bool has_high() const;
   };
-
+    
   typedef int var_origin;
+  const int model_name_origin = 0;
   const int data_origin = 1;
   const int transformed_data_origin = 2;
   const int parameter_origin = 3;
